[Openmp-commits] [clang] [clang-tools-extra] [compiler-rt] [flang] [libc] [lld] [lldb] [llvm] [mlir] [openmp] [llvm-project] Fix typo "seperate" (PR #95373)

via Openmp-commits openmp-commits at lists.llvm.org
Thu Jun 13 01:48:28 PDT 2024


llvmbot wrote:


<!--LLVM PR SUMMARY COMMENT-->
@llvm/pr-subscribers-clang-tools-extra
@llvm/pr-subscribers-lldb

@llvm/pr-subscribers-lld

Author: Jay Foad (jayfoad)

<details>
<summary>Changes</summary>



---

Patch is 57.75 KiB, truncated to 20.00 KiB below, full version: https://github.com/llvm/llvm-project/pull/95373.diff


64 Files Affected:

- (modified) clang-tools-extra/clangd/TidyProvider.cpp (+5-5) 
- (modified) clang/include/clang/Frontend/FrontendOptions.h (+1-1) 
- (modified) clang/include/clang/InstallAPI/DylibVerifier.h (+1-1) 
- (modified) clang/lib/InstallAPI/Visitor.cpp (+1-1) 
- (modified) clang/lib/Serialization/ASTWriterStmt.cpp (+1-1) 
- (modified) compiler-rt/test/dfsan/custom.cpp (+1-1) 
- (modified) compiler-rt/test/orc/TestCases/Linux/ppc64/trivial-tls-pwr10.test (+1-1) 
- (modified) flang/examples/FlangOmpReport/yaml_summarizer.py (+1-1) 
- (modified) flang/lib/Semantics/check-omp-structure.cpp (+5-5) 
- (modified) flang/test/Driver/mllvm_vs_mmlir.f90 (+1-1) 
- (modified) libc/src/__support/FPUtil/x86_64/FEnvImpl.h (+1-1) 
- (modified) libc/src/stdio/printf_core/float_hex_converter.h (+5-5) 
- (modified) libc/test/src/__support/str_to_float_comparison_test.cpp (+1-1) 
- (modified) lld/test/wasm/data-segments.ll (+1-1) 
- (modified) lldb/include/lldb/Expression/DWARFExpressionList.h (+1-1) 
- (modified) lldb/include/lldb/Target/MemoryTagManager.h (+1-1) 
- (modified) lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.cpp (+1-1) 
- (modified) lldb/test/API/CMakeLists.txt (+1-1) 
- (modified) lldb/test/API/tools/lldb-server/memory-tagging/TestGdbRemoteMemoryTagging.py (+1-1) 
- (modified) lldb/test/Shell/SymbolFile/DWARF/x86/DW_AT_data_bit_offset-DW_OP_stack_value.s (+1-1) 
- (modified) llvm/include/llvm/CodeGen/LiveRegUnits.h (+1-1) 
- (modified) llvm/include/llvm/CodeGen/MIRFormatter.h (+1-1) 
- (modified) llvm/include/llvm/MC/MCAsmInfo.h (+1-1) 
- (modified) llvm/include/llvm/Support/raw_socket_stream.h (+1-1) 
- (modified) llvm/lib/CodeGen/AsmPrinter/CodeViewDebug.h (+1-1) 
- (modified) llvm/lib/CodeGen/AssignmentTrackingAnalysis.cpp (+3-3) 
- (modified) llvm/lib/CodeGen/SelectionDAG/SelectionDAGBuilder.cpp (+2-2) 
- (modified) llvm/lib/FileCheck/FileCheck.cpp (+1-1) 
- (modified) llvm/lib/IR/DebugInfo.cpp (+1-1) 
- (modified) llvm/lib/MC/MCPseudoProbe.cpp (+1-1) 
- (modified) llvm/lib/Support/VirtualFileSystem.cpp (+1-1) 
- (modified) llvm/lib/Support/raw_socket_stream.cpp (+1-1) 
- (modified) llvm/lib/Target/ARM/ARMISelLowering.cpp (+1-1) 
- (modified) llvm/lib/Target/RISCV/RISCVMachineFunctionInfo.h (+1-1) 
- (modified) llvm/lib/TargetParser/RISCVISAInfo.cpp (+1-1) 
- (modified) llvm/lib/TextAPI/Utils.cpp (+1-1) 
- (modified) llvm/lib/Transforms/IPO/Attributor.cpp (+2-2) 
- (modified) llvm/lib/Transforms/IPO/SampleProfileProbe.cpp (+1-1) 
- (modified) llvm/lib/Transforms/Scalar/RewriteStatepointsForGC.cpp (+1-1) 
- (modified) llvm/lib/Transforms/Utils/LoopUnrollRuntime.cpp (+1-1) 
- (modified) llvm/test/CodeGen/X86/AMX/amx-greedy-ra.ll (+1-1) 
- (modified) llvm/test/CodeGen/X86/apx/shift-eflags.ll (+12-12) 
- (modified) llvm/test/CodeGen/X86/merge-consecutive-stores-nt.ll (+2-2) 
- (modified) llvm/test/CodeGen/X86/shift-eflags.ll (+12-12) 
- (modified) llvm/test/Transforms/InstSimplify/constant-fold-fp-denormal.ll (+1-1) 
- (modified) llvm/test/Transforms/LoopVectorize/LoongArch/defaults.ll (+1-1) 
- (modified) llvm/test/Transforms/LoopVectorize/RISCV/defaults.ll (+1-1) 
- (modified) llvm/test/Transforms/SeparateConstOffsetFromGEP/split-gep-or-as-add.ll (+1-1) 
- (modified) llvm/test/Verifier/alloc-size-failedparse.ll (+1-1) 
- (modified) llvm/test/tools/llvm-ar/windows-path.test (+1-1) 
- (modified) llvm/test/tools/llvm-objcopy/ELF/mirror-permissions-win.test (+1-1) 
- (modified) llvm/tools/llvm-cov/CodeCoverage.cpp (+1-1) 
- (modified) llvm/tools/llvm-profgen/PerfReader.cpp (+1-1) 
- (modified) llvm/unittests/Support/Path.cpp (+2-2) 
- (modified) mlir/include/mlir/Analysis/Presburger/IntegerRelation.h (+1-1) 
- (modified) mlir/include/mlir/Analysis/Presburger/PresburgerSpace.h (+1-1) 
- (modified) mlir/include/mlir/Dialect/OpenMP/OpenMPInterfaces.h (+1-1) 
- (modified) mlir/lib/Analysis/Presburger/PresburgerSpace.cpp (+1-1) 
- (modified) mlir/lib/Conversion/GPUCommon/GPUOpsLowering.h (+1-1) 
- (modified) mlir/lib/Dialect/LLVMIR/IR/BasicPtxBuilderInterface.cpp (+1-1) 
- (modified) mlir/lib/Target/LLVMIR/Dialect/OpenMP/OpenMPToLLVMIRTranslation.cpp (+3-3) 
- (modified) mlir/test/Integration/Dialect/SparseTensor/CPU/sparse_reduce_custom_prod.mlir (+1-1) 
- (modified) mlir/test/Target/LLVMIR/omptarget-constant-alloca-raise.mlir (+1-1) 
- (modified) openmp/tools/Modules/FindOpenMPTarget.cmake (+1-1) 


``````````diff
diff --git a/clang/include/clang/Frontend/FrontendOptions.h b/clang/include/clang/Frontend/FrontendOptions.h
index bd4981ca0ac08..ebb8e9e59c6b6 100644
--- a/clang/include/clang/Frontend/FrontendOptions.h
+++ b/clang/include/clang/Frontend/FrontendOptions.h
@@ -520,7 +520,7 @@ class FrontendOptions {
   std::string ProductName;
 
   // Currently this is only used as part of the `-extract-api` action.
-  // A comma seperated list of files providing a list of APIs to
+  // A comma separated list of files providing a list of APIs to
   // ignore when extracting documentation.
   std::vector<std::string> ExtractAPIIgnoresFileList;
 
diff --git a/clang/include/clang/InstallAPI/DylibVerifier.h b/clang/include/clang/InstallAPI/DylibVerifier.h
index ae0428abbb9c7..333f0cff077fd 100644
--- a/clang/include/clang/InstallAPI/DylibVerifier.h
+++ b/clang/include/clang/InstallAPI/DylibVerifier.h
@@ -135,7 +135,7 @@ class DylibVerifier : llvm::MachO::RecordVisitor {
 
   // Check if an internal declaration in zippered library has an
   // external declaration for a different platform. This results
-  // in the symbol being in a "seperate" platform slice.
+  // in the symbol being in a "separate" platform slice.
   bool shouldIgnoreInternalZipperedSymbol(const Record *R,
                                           const SymbolContext &SymCtx) const;
 
diff --git a/clang/lib/InstallAPI/Visitor.cpp b/clang/lib/InstallAPI/Visitor.cpp
index cf3aaa4c6ec93..367ae53b208b6 100644
--- a/clang/lib/InstallAPI/Visitor.cpp
+++ b/clang/lib/InstallAPI/Visitor.cpp
@@ -218,7 +218,7 @@ bool InstallAPIVisitor::VisitVarDecl(const VarDecl *D) {
   if (isa<ParmVarDecl>(D))
     return true;
 
-  // Skip variables in records. They are handled seperately for C++.
+  // Skip variables in records. They are handled separately for C++.
   if (D->getDeclContext()->isRecord())
     return true;
 
diff --git a/clang/lib/Serialization/ASTWriterStmt.cpp b/clang/lib/Serialization/ASTWriterStmt.cpp
index 1a98e30e0f89f..1ba6d5501fd10 100644
--- a/clang/lib/Serialization/ASTWriterStmt.cpp
+++ b/clang/lib/Serialization/ASTWriterStmt.cpp
@@ -37,7 +37,7 @@ namespace clang {
     unsigned AbbrevToUse;
 
     /// A helper that can help us to write a packed bit across function
-    /// calls. For example, we may write seperate bits in seperate functions:
+    /// calls. For example, we may write separate bits in separate functions:
     ///
     ///  void VisitA(A* a) {
     ///     Record.push_back(a->isSomething());
diff --git a/compiler-rt/test/dfsan/custom.cpp b/compiler-rt/test/dfsan/custom.cpp
index cede0d64dbcf2..54bb17cb4a035 100644
--- a/compiler-rt/test/dfsan/custom.cpp
+++ b/compiler-rt/test/dfsan/custom.cpp
@@ -2280,7 +2280,7 @@ void test_sscanf() {
   // %n, %s, %d, %f, and %% already tested
 }
 
-// Tested by a seperate source file.  This empty function is here to appease the
+// Tested by a separate source file.  This empty function is here to appease the
 // check-wrappers script.
 void test_fork() {}
 
diff --git a/compiler-rt/test/orc/TestCases/Linux/ppc64/trivial-tls-pwr10.test b/compiler-rt/test/orc/TestCases/Linux/ppc64/trivial-tls-pwr10.test
index 93561b1645c33..a393a009d2f5a 100644
--- a/compiler-rt/test/orc/TestCases/Linux/ppc64/trivial-tls-pwr10.test
+++ b/compiler-rt/test/orc/TestCases/Linux/ppc64/trivial-tls-pwr10.test
@@ -2,7 +2,7 @@
 // RUN: %clangxx -fPIC -c -o %t/main.o %S/Inputs/trivial-tls-main.cpp
 // RUN: %clangxx -fPIC -c -o %t/pwr10.o %S/Inputs/trivial-tls-pwr10.cpp
 // RUN: %llvm_jitlink %t/main.o %t/pwr10.o
-// FIXME: We seperate pwr10 code from main object file due to currrent
+// FIXME: We separate pwr10 code from main object file due to currrent
 // implementation only supports one PLT stub for the same symbol.
 // For example, `bl __tls_get_addr` in one object file has only one PLT stub,
 // however we need another different PLT stub for `bl __tls_get_addr at notoc`
diff --git a/flang/examples/FlangOmpReport/yaml_summarizer.py b/flang/examples/FlangOmpReport/yaml_summarizer.py
index 5726ff8da77f5..1e522c00aab8d 100644
--- a/flang/examples/FlangOmpReport/yaml_summarizer.py
+++ b/flang/examples/FlangOmpReport/yaml_summarizer.py
@@ -21,7 +21,7 @@
 Parameters:
 
     -d   --directory   Specify which directory to scan. Multiple directories can be searched by
-                       providing a semicolon seperated list of directories.
+                       providing a semicolon separated list of directories.
 
     -l   --log         Combine all yaml files into one log (instead of generating a summary)
 
diff --git a/flang/lib/Semantics/check-omp-structure.cpp b/flang/lib/Semantics/check-omp-structure.cpp
index 54ce45157537c..600f742721f02 100644
--- a/flang/lib/Semantics/check-omp-structure.cpp
+++ b/flang/lib/Semantics/check-omp-structure.cpp
@@ -2696,7 +2696,7 @@ void OmpStructureChecker::CheckIsLoopIvPartOfClause(
     }
   }
 }
-// Following clauses have a seperate node in parse-tree.h.
+// Following clauses have a separate node in parse-tree.h.
 // Atomic-clause
 CHECK_SIMPLE_PARSER_CLAUSE(OmpAtomicRead, OMPC_read)
 CHECK_SIMPLE_PARSER_CLAUSE(OmpAtomicWrite, OMPC_write)
@@ -2802,18 +2802,18 @@ void OmpStructureChecker::CheckAllowedMapTypes(
     const parser::OmpMapType::Type &type,
     const std::list<parser::OmpMapType::Type> &allowedMapTypeList) {
   if (!llvm::is_contained(allowedMapTypeList, type)) {
-    std::string commaSeperatedMapTypes;
+    std::string commaSeparatedMapTypes;
     llvm::interleave(
         allowedMapTypeList.begin(), allowedMapTypeList.end(),
         [&](const parser::OmpMapType::Type &mapType) {
-          commaSeperatedMapTypes.append(parser::ToUpperCaseLetters(
+          commaSeparatedMapTypes.append(parser::ToUpperCaseLetters(
               parser::OmpMapType::EnumToString(mapType)));
         },
-        [&] { commaSeperatedMapTypes.append(", "); });
+        [&] { commaSeparatedMapTypes.append(", "); });
     context_.Say(GetContext().clauseSource,
         "Only the %s map types are permitted "
         "for MAP clauses on the %s directive"_err_en_US,
-        commaSeperatedMapTypes, ContextDirectiveAsFortran());
+        commaSeparatedMapTypes, ContextDirectiveAsFortran());
   }
 }
 
diff --git a/flang/test/Driver/mllvm_vs_mmlir.f90 b/flang/test/Driver/mllvm_vs_mmlir.f90
index 99c3418dc6a1f..074843fe99368 100644
--- a/flang/test/Driver/mllvm_vs_mmlir.f90
+++ b/flang/test/Driver/mllvm_vs_mmlir.f90
@@ -1,6 +1,6 @@
 ! Verify that `-mllvm` options are forwarded to LLVM and `-mmlir` to MLIR.
 
-! In practice, '-mmlir --help' is a super-set of '-mllvm --help' and that limits what we can test here. With a better seperation of
+! In practice, '-mmlir --help' is a super-set of '-mllvm --help' and that limits what we can test here. With a better separation of
 ! LLVM, MLIR and Flang global options, we should be able to write a stricter test.
 
 ! RUN: %flang_fc1  -mmlir --help | FileCheck %s --check-prefix=MLIR
diff --git a/libc/src/__support/FPUtil/x86_64/FEnvImpl.h b/libc/src/__support/FPUtil/x86_64/FEnvImpl.h
index a157b81aaaf32..2aa69565efc58 100644
--- a/libc/src/__support/FPUtil/x86_64/FEnvImpl.h
+++ b/libc/src/__support/FPUtil/x86_64/FEnvImpl.h
@@ -248,7 +248,7 @@ LIBC_INLINE int raise_except(int excepts) {
   // of the "Intel 64 and IA-32 Architectures Software Developer's
   // Manual, Vol 1".
 
-  // FPU status word is read for each exception seperately as the
+  // FPU status word is read for each exception separately as the
   // exception handler can potentially write to it (typically to clear
   // the corresponding exception flag). By reading it separately, we
   // ensure that the writes by the exception handler are maintained
diff --git a/libc/src/stdio/printf_core/float_hex_converter.h b/libc/src/stdio/printf_core/float_hex_converter.h
index 68a4ba6209d09..8fac36df3d1e2 100644
--- a/libc/src/stdio/printf_core/float_hex_converter.h
+++ b/libc/src/stdio/printf_core/float_hex_converter.h
@@ -199,13 +199,13 @@ LIBC_INLINE int convert_float_hex_exp(Writer *writer,
   constexpr cpp::string_view HEXADECIMAL_POINT(".");
 
   // This is for the letter 'p' before the exponent.
-  const char exp_seperator = a + ('p' - 'a');
-  constexpr int EXP_SEPERATOR_LEN = 1;
+  const char exp_separator = a + ('p' - 'a');
+  constexpr int EXP_SEPARATOR_LEN = 1;
 
   padding = static_cast<int>(to_conv.min_width - (sign_char > 0 ? 1 : 0) -
                              PREFIX_LEN - mant_digits - trailing_zeroes -
                              static_cast<int>(has_hexadecimal_point) -
-                             EXP_SEPERATOR_LEN - (EXP_LEN - exp_cur));
+                             EXP_SEPARATOR_LEN - (EXP_LEN - exp_cur));
   if (padding < 0)
     padding = 0;
 
@@ -223,7 +223,7 @@ LIBC_INLINE int convert_float_hex_exp(Writer *writer,
       RET_IF_RESULT_NEGATIVE(writer->write({mant_buffer + 1, mant_digits - 1}));
     if (trailing_zeroes > 0)
       RET_IF_RESULT_NEGATIVE(writer->write('0', trailing_zeroes));
-    RET_IF_RESULT_NEGATIVE(writer->write(exp_seperator));
+    RET_IF_RESULT_NEGATIVE(writer->write(exp_separator));
     RET_IF_RESULT_NEGATIVE(
         writer->write({exp_buffer + exp_cur, EXP_LEN - exp_cur}));
     if (padding > 0)
@@ -247,7 +247,7 @@ LIBC_INLINE int convert_float_hex_exp(Writer *writer,
       RET_IF_RESULT_NEGATIVE(writer->write({mant_buffer + 1, mant_digits - 1}));
     if (trailing_zeroes > 0)
       RET_IF_RESULT_NEGATIVE(writer->write('0', trailing_zeroes));
-    RET_IF_RESULT_NEGATIVE(writer->write(exp_seperator));
+    RET_IF_RESULT_NEGATIVE(writer->write(exp_separator));
     RET_IF_RESULT_NEGATIVE(
         writer->write({exp_buffer + exp_cur, EXP_LEN - exp_cur}));
   }
diff --git a/libc/test/src/__support/str_to_float_comparison_test.cpp b/libc/test/src/__support/str_to_float_comparison_test.cpp
index 19f3f869f3c4c..7641c594c3d3b 100644
--- a/libc/test/src/__support/str_to_float_comparison_test.cpp
+++ b/libc/test/src/__support/str_to_float_comparison_test.cpp
@@ -143,7 +143,7 @@ int main(int argc, char *argv[]) {
   int fails = 0;
 
   // Bitdiffs are cases where the expected result and actual result only differ
-  // by +/- the least significant bit. They are tracked seperately from larger
+  // by +/- the least significant bit. They are tracked separately from larger
   // failures since a bitdiff is most likely the result of a rounding error, and
   // splitting them off makes them easier to track down.
   int bitdiffs = 0;
diff --git a/lld/test/wasm/data-segments.ll b/lld/test/wasm/data-segments.ll
index 7ff949794d8e9..9354e6c8e4d2b 100644
--- a/lld/test/wasm/data-segments.ll
+++ b/lld/test/wasm/data-segments.ll
@@ -161,7 +161,7 @@
 ; DIS-EMPTY:
 ; DIS-NEXT:        end
 
-; In PIC mode __wasm_apply_data_relocs is export seperatly to __wasm_call_ctors
+; In PIC mode __wasm_apply_data_relocs is export separatly to __wasm_call_ctors
 ; PIC-DIS:     <__wasm_apply_data_relocs>:
 ; PIC-DIS-EMPTY:
 
diff --git a/lldb/include/lldb/Expression/DWARFExpressionList.h b/lldb/include/lldb/Expression/DWARFExpressionList.h
index f711a1cbe9bbd..664c2603770f6 100644
--- a/lldb/include/lldb/Expression/DWARFExpressionList.h
+++ b/lldb/include/lldb/Expression/DWARFExpressionList.h
@@ -92,7 +92,7 @@ class DWARFExpressionList {
                      lldb::addr_t func_load_addr, lldb::addr_t file_addr,
                      ABI *abi) const;
 
-  /// Dump all locaitons with each seperated by new line.
+  /// Dump all locaitons with each separated by new line.
   void GetDescription(Stream *s, lldb::DescriptionLevel level, ABI *abi) const;
 
   /// Search for a load address in the dwarf location list
diff --git a/lldb/include/lldb/Target/MemoryTagManager.h b/lldb/include/lldb/Target/MemoryTagManager.h
index b082224c38edb..6bd4180fff703 100644
--- a/lldb/include/lldb/Target/MemoryTagManager.h
+++ b/lldb/include/lldb/Target/MemoryTagManager.h
@@ -103,7 +103,7 @@ class MemoryTagManager {
   // transport.
   virtual size_t GetTagSizeInBytes() const = 0;
 
-  // Unpack tags from their stored format (e.g. gdb qMemTags data) into seperate
+  // Unpack tags from their stored format (e.g. gdb qMemTags data) into separate
   // tags.
   //
   // Checks that each tag is within the expected value range and if granules is
diff --git a/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.cpp b/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.cpp
index 9b5f7aef1efe5..5397e90022f39 100644
--- a/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.cpp
+++ b/lldb/source/Plugins/Process/Linux/NativeRegisterContextLinux_arm64.cpp
@@ -388,7 +388,7 @@ NativeRegisterContextLinux_arm64::ReadRegister(const RegisterInfo *reg_info,
           return error;
       }
 
-      // ZA is part of the SME set but uses a seperate member buffer for
+      // ZA is part of the SME set but uses a separate member buffer for
       // storage. Therefore its effective byte offset is always 0 even if it
       // isn't 0 within the SME register set.
       src = (uint8_t *)GetZABuffer() + GetZAHeaderSize();
diff --git a/lldb/test/API/CMakeLists.txt b/lldb/test/API/CMakeLists.txt
index 856beb894208c..27f285230cafa 100644
--- a/lldb/test/API/CMakeLists.txt
+++ b/lldb/test/API/CMakeLists.txt
@@ -36,7 +36,7 @@ set(LLDB_TEST_ARCH
 # Users can override LLDB_TEST_USER_ARGS to specify arbitrary arguments to pass to the script
 set(LLDB_TEST_USER_ARGS
   ""
-  CACHE STRING "Specify additional arguments to pass to test runner. Seperate \
+  CACHE STRING "Specify additional arguments to pass to test runner. Separate \
 items with \";\". For example: '-C;gcc;-C;clang;-A;i386;-A;x86_64'")
 
 set(LLDB_TEST_COMMON_ARGS_VAR
diff --git a/lldb/test/API/tools/lldb-server/memory-tagging/TestGdbRemoteMemoryTagging.py b/lldb/test/API/tools/lldb-server/memory-tagging/TestGdbRemoteMemoryTagging.py
index 6ddd264057c3c..87507583724e6 100644
--- a/lldb/test/API/tools/lldb-server/memory-tagging/TestGdbRemoteMemoryTagging.py
+++ b/lldb/test/API/tools/lldb-server/memory-tagging/TestGdbRemoteMemoryTagging.py
@@ -170,7 +170,7 @@ def test_tag_write_QMemTags_packets(self):
         self.check_tag_write("{:x},20".format(buf_address), "E03")
         # Missing data
         self.check_tag_write("{:x},20:1".format(buf_address), "E03")
-        # Zero length write must still include seperator after type
+        # Zero length write must still include separator after type
         self.check_tag_write("{:x},0:1".format(buf_address), "E03")
         # Empty address
         self.check_tag_write(",10:1:01", "E03")
diff --git a/lldb/test/Shell/SymbolFile/DWARF/x86/DW_AT_data_bit_offset-DW_OP_stack_value.s b/lldb/test/Shell/SymbolFile/DWARF/x86/DW_AT_data_bit_offset-DW_OP_stack_value.s
index 074da09bc61ee..f82dd19466e63 100644
--- a/lldb/test/Shell/SymbolFile/DWARF/x86/DW_AT_data_bit_offset-DW_OP_stack_value.s
+++ b/lldb/test/Shell/SymbolFile/DWARF/x86/DW_AT_data_bit_offset-DW_OP_stack_value.s
@@ -51,7 +51,7 @@
 #
 #   DW_AT_location	(DW_OP_constu 0x64a40101, DW_OP_stack_value)
 #
-# to work-around a seperate bug.
+# to work-around a separate bug.
 
 .zerofill __DATA,__bss,__type_anchor,4,2 ## @_type_anchor
 .zerofill __DATA,__bss,_ug.0,1,2        ## @ug.0
diff --git a/llvm/include/llvm/CodeGen/LiveRegUnits.h b/llvm/include/llvm/CodeGen/LiveRegUnits.h
index e96165d6b3bbf..405a9c123d041 100644
--- a/llvm/include/llvm/CodeGen/LiveRegUnits.h
+++ b/llvm/include/llvm/CodeGen/LiveRegUnits.h
@@ -43,7 +43,7 @@ class LiveRegUnits {
   /// For a machine instruction \p MI, adds all register units used in
   /// \p UsedRegUnits and defined or clobbered in \p ModifiedRegUnits. This is
   /// useful when walking over a range of instructions to track registers
-  /// used or defined seperately.
+  /// used or defined separately.
   static void accumulateUsedDefed(const MachineInstr &MI,
                                   LiveRegUnits &ModifiedRegUnits,
                                   LiveRegUnits &UsedRegUnits,
diff --git a/llvm/include/llvm/CodeGen/MIRFormatter.h b/llvm/include/llvm/CodeGen/MIRFormatter.h
index 42087f549426b..ab2244f255f3b 100644
--- a/llvm/include/llvm/CodeGen/MIRFormatter.h
+++ b/llvm/include/llvm/CodeGen/MIRFormatter.h
@@ -46,7 +46,7 @@ class MIRFormatter {
   }
 
   /// Implement target specific parsing of immediate mnemonics. The mnemonic is
-  /// dot seperated strings.
+  /// dot separated strings.
   virtual bool parseImmMnemonic(const unsigned OpCode, const unsigned OpIdx,
                                 StringRef Src, int64_t &Imm,
                                 ErrorCallbackType ErrorCallback) const {
diff --git a/llvm/include/llvm/MC/MCAsmInfo.h b/llvm/include/llvm/MC/MCAsmInfo.h
index f9dd6012d5e94..48056b6ad6137 100644
--- a/llvm/include/llvm/MC/MCAsmInfo.h
+++ b/llvm/include/llvm/MC/MCAsmInfo.h
@@ -393,7 +393,7 @@ class MCAsmInfo {
   /// for ELF targets.  Defaults to true.
   bool HasSingleParameterDotFile = true;
 
-  /// True if the target has a four strings .file directive, strings seperated
+  /// True if the target has a four strings .file directive, strings separated
   /// by comma. Defaults to false.
   bool HasFourStringsDotFile = false;
 
diff --git a/llvm/include/llvm/Support/raw_socket_stream.h b/llvm/include/llvm/Support/raw_socket_stream.h
index bddd47eb75e1a..eed865fb5af49 100644
--- a/llvm/include/llvm/Support/raw_socket_stream.h
+++ b/llvm/include/llvm/Support/raw_socket_stream.h
@@ -61,7 +61,7 @@ class ListeningSocket {
   std::atomic<int> FD;
   std::string SocketPath; // Not modified after construction
 
-  /// If a seperate thread calls ListeningSocket::shutdown, the ListeningSocket
+  /// If a separate thread calls ListeningSocket::shutdown, the ListeningSocket
   /// file descriptor (FD) could be closed while ::poll is waiting for it to be
   /// ready to perform a I/O operations. ::poll will continue to block even
   /// after FD is closed so use a self-pipe mechanism to get ::poll to return
diff --git a/llvm/lib/CodeGen/AsmPrinter/CodeViewDebug.h b/llvm/lib/CodeGen/AsmPrinter/CodeViewDebug.h
index 4c03bf79d04da..55d149e049c94 100644
--- a/llvm/lib/CodeGen/AsmPrinter/CodeViewDebug.h
+++ b/llvm/lib/CodeGen/AsmPrinter/CodeViewDebug.h
@@ -220,7 +220,7 @@ class LLVM_LIBRARY_VISIBILITY CodeViewDebug : public DebugHandlerBase {
   // DIGlobalVariableExpression referencing the DIGlobalVariable.
   DenseMap<const DIGlobalVariable *, uint64_t> CVGlobalVariableOffsets;
 
-  // Map used to seperate variables according to the lexical scope they belong
+  // Map used to separate variables according to the lexical scope they belong
   // in.  This is populated by recordLocalVariable() before
   // collectLexicalBlocks() separates the variables between the FunctionInfo
   // and LexicalBlocks.
diff --git a/clang-tools-extra/clangd/TidyProvider.cpp b/clang-tools-extra/clangd/TidyProvider.cpp
index a4121df30d3df..a87238e0c0938 100644
--- a/clang-tools-extra/clangd/TidyProvider.cpp
+++ b/clang-tools-extra/clangd/TidyProvider.cpp
@@ -195,10 +195,10 @@ TidyProvider addTidyChecks(llvm::StringRef Checks,
 }
 
 TidyProvider disableUnusableChecks(llvm::ArrayRef<std::string> ExtraBadChecks) {
-  constexpr llvm::StringLiteral Seperator(",");
+  constexpr llvm::StringLiteral Separator(",");
   static const std::string BadChecks = llvm::join_items(
-      Seperator,
-      // We want this list to start with a seperator to
+      Separator,
+      // We want this list to start with a separator to
       // simplify appending in the lambda. So including an
       // empty string here will force that.
       "",
@@ -227,7 +227,7 @@ TidyProvider disableUnusableChecks(llvm::ArrayRef<std::string> ExtraBadChecks) {
   for (const std::string &Str : ExtraBadChecks) {
     if (Str.empty())
       continue;
-    Size += Seperator.size();
+    Size += Separator.size();
     if (LLVM_LIKELY(Str.front() != '-'))
       ++Size;
     Size += Str.size();
@@ -238,7 +238,7 @@ TidyProvider disableUnusableChecks(llvm::ArrayRef<std::string> ExtraBadChecks) {
   for (const std::string &Str : ExtraBadChecks) {
     if (Str.empty())
       continue;
-    DisableGlob += Seperator;
+    DisableGlob += Separator;
     if (LLVM_LIKELY(Str.front() != '-'))
       DisableGlob.push_back('-');
     DisableGlob += Str;
diff --git a/llvm/lib/CodeGen/AssignmentTrackingAnalysis.cpp b/llvm/lib/CodeGen/AssignmentTrackingAnalysis.cpp
index ec5fc06d01fb1..8afd75069589e 100644
--- a/llvm/lib/CodeGen/AssignmentTrackingAn...
[truncated]

``````````

</details>


https://github.com/llvm/llvm-project/pull/95373


More information about the Openmp-commits mailing list